##  Creating a New Report
To create a new report, you can click on the New Report button and choose Report Type. You can choose from 4 types of reports: Matrix, Portfolio, Roadmap, and Landscape Report.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a1beb7a441014bc23f670e866d0ed_LowRes.png)
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27534e6c7a44101491a293bba7fcd0b5_LowRes.png)
